
/*
Copyright 2007-2008 Kim A. Brandt <kimabrandt@gmx.de>

This file is part of yarip.

Yarip is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

Yarip is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with yarip; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

function YaripElement(xpath, deep, dow, force, style, found, notFound, ignored)
{
	this.xpath = "";
	this.deep = true;
	this.dow = false;
	this.force = false;
	this.style = null;
	this.found = 0;
	this.notFound = 0;
	this.ignored = 0;

	this.getKey = function()
	{
		return this.getXPath();
	}

	this.setXPath = function(xpath)
	{
		if (xpath) this.xpath = "" + xpath;
	}

	this.getXPath = function()
	{
		return this.xpath;
	}

	this.setDeep = function(deep, noStyle)
	{
		this.deep = "" + deep != "false";
		if (!this.deep && !noStyle) this.style = null;
	}

	this.getDeep = function()
	{
		return this.deep;
	}

	this.setDOW = function(dow)
	{
		this.dow = "" + dow == "true";
	}

	this.getDOW = function()
	{
		return this.dow;
	}

	this.setForce = function(force)
	{
		this.force = "" + force == "true";
		if (!this.force) this.style = null;
	}

	this.getForce = function()
	{
		return this.force;
	}

	this.setStyle = function(style)
	{
		if (style) this.style = style;
	}

	this.getStyle = function()
	{
		return this.style;
	}

	this.setFound = function(found)
	{
		found = Number(found);
		if (typeof found != "number" || found + "" == "NaN") return;
		this.found = found;
	}

	this.getFound = function()
	{
		return this.found;
	}

	this.incrementFound = function()
	{
		this.found++;
	}

	this.setNotFound = function(notFound)
	{
		notFound = Number(notFound);
		if (typeof notFound != "number" || notFound + "" == "NaN") return;
		this.notFound = notFound;
	}

	this.getNotFound = function()
	{
		return this.notFound;
	}

	this.incrementNotFound = function()
	{
		this.notFound++;
	}

	this.setIgnored = function(ignored)
	{
		ignored = Number(ignored);
		if (typeof ignored != "number" || ignored + "" == "NaN") return;
		this.ignored = ignored;
	}

	this.getIgnored = function()
	{
		return this.ignored;
	}

	this.incrementIgnored = function()
	{
		this.ignored++;
	}

	this.purge = function()
	{
		this.found = 0;
		this.notFound = 0;
		this.ignored = 0;
	}

	this.clone = function(purge)
	{
		var tmp = new this.constructor(this.xpath, this.deep, this.dow, this.force, this.style, this.found, this.notFound, this.ignored);
		for (var k in this) if (this[k] && typeof(this[k]) != "object" && !/^(xpath|deep|dow|force|style|found|notFound|ignored)$/.test(k)) tmp[k] = this[k];
		if (purge) tmp.purge();
		return tmp;
	}

	this.merge = function(o)
	{
		if (!o) return;
		this.setDeep(o.getDeep() && this.getDeep());
		this.setDOW(o.getDOW() || this.getDOW());
		this.setForce(o.getForce() || this.getForce());
		this.setStyle(o.getStyle() || this.getStyle());
		this.setFound(o.getFound() + this.getFound());
		this.setNotFound(o.getNotFound() + this.getNotFound());
		this.setIgnored(o.getIgnored() + this.getIgnored());
	}

	this.generateXml = function()
	{
		var r = "\t\t\t<element xpath=\"" + this.xpath + "\"";
		if (this.deep == false) r += " deep=\"false\"";
		if (this.dow == true) r += " dow=\"true\"";
		if (this.force == true) r += " force=\"true\"";
		if (this.style) r += " style=\"" + this.style + "\"";
		if (this.found > 0) r += " found=\"" + this.found + "\"";
		if (this.notFound > 0) r += " notFound=\"" + this.notFound + "\"";
		if (this.ignored > 0) r += " ignored=\"" + this.ignored + "\"";
		r += "/>\n";
		return r;
	}

	this.createStyle = function(force)
	{
		if (/*!this.force ||*/ !force && this.style) return;
		this.style = null;
		if (!this.deep || !/^\/?(\/([a-z][\w]*|\*)(\[@[a-z][\w]*='[^']*'\])*)+$/i.test(this.xpath)) return;
		this.style = this.xpath.replace(/^\/+/, "").replace(/(([a-z][\w]*|\*)(\[@[a-z][\w]*='[^']*'\])*)\//gi, "$1 > ").replace(/\[@/g, "\[");
	}

	this.xpathToStyle = function()
	{
		if (!/^\/?(\/([a-z][\w]*|\*)(\[@[a-z][\w]*='[^']*'\])*)+$/i.test(this.xpath)) return null;
		return this.xpath.replace(/^\/+/, "").replace(/(([a-z][\w]*|\*)(\[@[a-z][\w]*='[^']*'\])*)\//gi, "$1 > ").replace(/\[@/g, "\[");
	}

	this.generateCSS = function()
	{
		if (this.style) return "\t" + this.style + ",\n";
		else return "";
	}

	this.setXPath(xpath);
	this.setDeep(deep);
	this.setDOW(dow);
	this.setForce(force);
	this.setStyle(style);
	this.setFound(found);
	this.setNotFound(notFound);
	this.setIgnored(ignored);
}

function YaripContent(type, regexp, deep, dow, force, found, ignored)
{
	this.type = "all";
	this.typeIndex = 0;
	this.regexp = "";
	this.regexpobj = null;
	this.deep = true;
	this.dow = false;
	this.force = false;
	this.found = 0;
	this.ignored = 0;

	this.getKey = function()
	{
//		return this.getTypeText() + this.getRegExp();
//		return this.getType() + this.getRegExp();
		return this.getRegExp();
	}

	this.setType = function(type)
	{
		if (!type) return;

		switch (type)
		{
			case "all":
				this.type = "all";
				this.typeIndex = 0;
				break;

			case "other":
				this.type = "other";
				this.typeIndex = 1;
				break;

			case "script":
				this.type = "script";
				this.typeIndex = 2;
				break;

			case "image":
				this.type = "image";
				this.typeIndex = 3;
				break;

			case "stylesheet":
				this.type = "stylesheet";
				this.typeIndex = 4;
				break;

			case "object":
				this.type = "object";
				this.typeIndex = 5;
				break;

			case "document":
				this.type = "document";
				this.typeIndex = 6;
				break;

			case "subdocument":
				this.type = "subdocument";
				this.typeIndex = 7;
				break;

			case "refresh":
				this.type = "refresh";
				this.typeIndex = 8;
				break;

			case "xbl":
				this.type = "xbl";
				this.typeIndex = 9;
				break;

			case "ping":
				this.type = "ping";
				this.typeIndex = 10;
				break;

			case "xmlhttprequest":
				this.type = "xmlhttprequest";
				this.typeIndex = 11;
				break;

			case "object_subrequest":
				this.type = "object_subrequest";
				this.typeIndex = 12;
				break;

			default:
				this.type = "all";
				this.typeIndex = 0;
		}
	}

	this.getType = function()
	{
		return this.type;
	}

	this.getTypeIndex = function()
	{
		return this.typeIndex;
	}

	this.setRegExp = function(regexp)
	{
		if (!regexp) return;

		this.regexp = regexp;
		this.setRegExpObj(regexp);
	}

	this.getRegExp = function()
	{
		return this.regexp;
	}

	this.setRegExpObj = function(regexp)
	{
		if (regexp) this.regexpobj = new RegExp(regexp);
	}

	this.getRegExpObj = function()
	{
		return this.regexpobj;
	}

	this.setDeep = function(deep)
	{
		this.deep = "" + deep != "false";
	}

	this.getDeep = function()
	{
		return this.deep;
	}

	this.setDOW = function(dow)
	{
		this.dow = "" + dow == "true";
	}

	this.getDOW = function()
	{
		return this.dow;
	}

	this.setForce = function(force)
	{
		this.force = "" + force == "true";
	}

	this.getForce = function()
	{
		return this.force;
	}

	this.setFound = function(found)
	{
		found = Number(found);
		if (typeof found != "number" || found + "" == "NaN") return;
		this.found = found;
	}

	this.getFound = function()
	{
		return this.found;
	}

	this.incrementFound = function()
	{
		this.found++;
	}

	this.setIgnored = function(ignored)
	{
		ignored = Number(ignored);
		if (typeof ignored != "number" || ignored + "" == "NaN") return;
		this.ignored = ignored;
	}

	this.getIgnored = function()
	{
		return this.ignored;
	}

	this.incrementIgnored = function()
	{
		this.ignored++;
	}

	this.purge = function()
	{
		this.found = 0;
		this.ignored = 0;
	}

	this.clone = function(purge)
	{
		var tmp = new this.constructor(this.type, this.regexp, this.deep, this.dow, this.force, this.found, this.ignored);
		for (var k in this) if (this[k] && typeof(this[k]) != "object" && !/^(type|regexp|deep|dow|force|found|ignored)$/.test(k)) tmp[k] = this[k];
		if (purge) tmp.purge();
		return tmp;
	}

	this.merge = function(o)
	{
		if (!o) return;
		this.setRegExp(o.getRegExp() || this.getRegExp());
		this.setDeep(o.getDeep() && this.getDeep());
		this.setDOW(o.getDOW() || this.getDOW());
		this.setForce(o.getForce() || this.getForce());
		this.setFound(o.getFound() + this.getFound());
		this.setIgnored(o.getIgnored() + this.getIgnored());
	}

	this.generateXml = function()
	{
		var r = "\t\t\t<content";
//		if (this.type) r += " type=\"" + this.type + "\"";
		if (this.regexp) r += " regexp=\"" + this.regexp + "\"";
		if (this.deep == false) r += " deep=\"false\"";
		if (this.dow == true) r += " dow=\"true\"";
		if (this.force == true) r += " force=\"true\"";
		if (this.found > 0) r += " found=\"" + this.found + "\"";
		if (this.ignored > 0) r += " ignored=\"" + this.ignored + "\"";
		r += "/>\n";
		return r;
	}

	this.setType(type);
	this.setRegExp(regexp);
	this.setDeep(deep);
	this.setDOW(dow);
	this.setForce(force);
	this.setFound(found);
	this.setIgnored(ignored);
}

function YaripItem(value)
{
	this.value = "";

	this.getKey = function()
	{
		return this.value;
	}

	this.setValue = function(value)
	{
		if (value) this.value = "" + value;
	}

	this.getValue = function()
	{
		return this.value;
	}

	this.clone = function()
	{
		return new this.constructor(this.value);
	}

	this.merge = function(o)
	{
	}

	this.generateXml = function()
	{
		return "\t\t\t<item value=\"" + this.value + "\"/>\n";
	}

	this.setValue(value);
}

